@@ -1,10 +1,7 @@
 import os
-import io
 import re
-import string
 import sre_parse
 import sre_compile
-from collections import OrderedDict, namedtuple
 from sre_constants import BRANCH, SUBPATTERN
 import hashlib
 from . import utils
@@ -18,35 +15,16 @@ from . import utils
 # TODO: Simplify this. You don't need group pattern detection.
 
 
-
-Method = namedtuple('Method', ['definition', 'signature', 'body', 'sha1'])
-
-class LastUpdatedOrderedDict(OrderedDict):
-    """Store items in the order the keys were last added."""
-
-    def __setitem__(self, key, value):
-        if key in self:
-            del self[key]
-        OrderedDict.__setitem__(self, key, value)
-
-
 class GroovyScripts(object):
     """
     Store and manage an index of Gremlin-Groovy scripts.
 
-    :parm config: Config object.
-    :type config: bulbs.Config
-
     :param file_path: Path to the base Groovy scripts file.
     :type file_path: str
 
-    :ivar config: Config object.
-
     :ivar source_files: List containing the absolute paths to the script files,
                         in the order they were added.
-    :ivar methods: LastUpdatedOrderedDict mapping Groovy method names to the 
-                   Python Method object, which is a namedtuple containing the 
-                   Groovy script's definition, signature, body, and sha1.
+    :ivar methods: Dict mapping Groovy method names to the actual scripts.
 
     .. note:: Use the update() method to add subsequent script files. 
               Order matters. Groovy methods are overridden if subsequently added
@@ -56,25 +34,17 @@ class GroovyScripts(object):
     #: Relative path to the default script file
     default_file = "gremlin.groovy"
 
-    def __init__(self, config, file_path=None):
-        self.config = config
+    def __init__(self, file_path=None):
+        self.source_files = list()  # an ordered set might be better
 
-        self.source_file_map = OrderedDict()   # source_file_map[file_path] = namespace
-
-        # may have model-specific namespaces
-        # methods format: methods[method_name] = method_object
-        self.namespace_map = OrderedDict()     # namespace_map[namespace] = methods
+        # methods format: methods[method_name] = method_body
+        self.methods = dict()
 
         if file_path is None:
             file_path = self._get_default_file()
-        # default_namespace is derifed from the default_file so
-        # default_namespace will be "gremlin" assuming you don't change default_file
-        # or override default_file by passing in an explicit file_path
-        self.default_namespace = self._get_filename(file_path) 
-        self.update(file_path, self.default_namespace)
+        self.update(file_path)
 
-
-    def get(self, method_name, namespace=None):
+    def get(self, method_name):
         """
         Returns the Groovy script with the method name.
         
@@ -84,32 +54,11 @@ class GroovyScripts(object):
         :rtype: str
 
         """
-        # Example: my_method                # uses default_namespace
-        #          my_method, my_namespace  # pass in namespace as an arg
-        #          my_namespace:my_method   # pass in  namespace via a method_name prefix
-        method = self.get_method(method_name, namespace)
-        script = method.signature if self.config.server_scripts is True else method.body 
+        return self.methods[method_name]
         #script = self._build_script(method_definition, method_signature)
-        return script
+        #return script
 
-    def get_methods(self, namespace):
-        return self.namespace_map[namespace]
-
-    def get_method(self, method_name, namespace=None):
-        """
-        Returns a Python namedtuple for the Groovy script with the method name.
-        
-        :param method_name: Name of a Groovy method.
-        :type method_name: str
-
-        :rtype: bulbs.groovy.Method
-
-        """
-        namespace, method_name = self._get_namespace_and_method_name(method_name, namespace)
-        methods = self.get_methods(namespace)
-        return methods[method_name]
- 
-    def update(self, file_path, namespace=None):
+    def update(self, file_path):
         """
         Updates the script index with the Groovy methods in the script file.
 
@@ -118,11 +67,8 @@ class GroovyScripts(object):
         """
         file_path = os.path.abspath(file_path)
         methods = self._get_methods(file_path)
-        if namespace is None:
-            namespace = self._get_filename(file_path)
-        self._maybe_create_namespace(namespace)
-        self.source_file_map[file_path] = namespace
-        self.namespace_map[namespace].update(methods)
+        self._add_source_file(file_path)
+        self.methods.update(methods)
 
     def refresh(self):
         """
@@ -131,30 +77,13 @@ class GroovyScripts(object):
         :rtype: None
 
         """
-        for file_path in self.source_file_map:
-            namespace = self.source_file_map[file_path]
+        for file_path in self.source_files:
             methods = self._get_methods(file_path)
-            self.namespace_map[namespace].update(methods)
+            self.methods.update(methods)
 
-    def _maybe_create_namespace(self, namespace):
-        if namespace not in self.namespace_map:
-            methods = LastUpdatedOrderedDict()
-            self.namespace_map[namespace] = methods
-
-    def _get_filename(self, file_path):
-        base_name = os.path.basename(file_path)
-        file_name, file_ext = os.path.splitext(base_name)
-        return file_name
-
-    def _get_namespace_and_method_name(self, method_name, namespace=None):
-        if namespace is None:
-            namespace = self.default_namespace
-        parts = method_name.split(":") 
-        if len(parts) == 2:
-            # a namespace explicitly set in method_name takes precedent
-            namespace = parts[0]
-            method_name = parts[1]
-        return namespace, method_name
+    def _add_source_file(self,file_path):
+        # order matters (last in takes precedence if it overrides a method)
+        self.source_files.append(file_path)
 
     def _get_methods(self,file_path):
         return Parser(file_path).get_methods()
@@ -241,7 +170,7 @@ class Scanner:
             callback(self,match.group(1))
 
     def scan(self,file_path):
-        fin = io.open(file_path, 'r', encoding='utf-8')    
+        fin = open(file_path, 'r')    
         for line in fin:
             self.get_item(fin,line)
 
@@ -249,7 +178,7 @@ class Scanner:
 class Parser(object):
 
     def __init__(self, groovy_file):
-        self.methods = OrderedDict()
+        self.methods = {}
         # handler format: (pattern, callback)
         handlers = [ ("^def( .*)", self.add_method), ]
         Scanner(handlers).scan(groovy_file)
@@ -267,11 +196,9 @@ class Parser(object):
         # because of the way the GSE works. It's easier to handle version
         # control by just using the method_body, which the GSE compiles,
         # creates a class out of, and stores in a classMap for reuse.
-        # You can't do imports inside Groovy methods so just using the func body 
-        sha1 = self._get_sha1(method_definition)
+        #sha1 = self._get_sha1(method_definition)
         #self.methods[method_name] = (method_signature, method_definition, sha1)
-        method = Method(method_definition, method_signature, method_body, sha1)
-        self.methods[method_name] = method
+        self.methods[method_name] = method_body
 
     def _get_method_signature(self,method_definition):
         pattern = '^def(.*){'
@@ -290,9 +217,8 @@ class Parser(object):
 
     def _get_sha1(self,method_definition):
         # this is used to detect version changes
-        method_definition_bytes = method_definition.encode('utf-8')
         sha1 = hashlib.sha1()
-        sha1.update(method_definition_bytes)
+        sha1.update(method_definition)
         return sha1.hexdigest()
 
 
