@@ -843,7 +843,8 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        key, value = quote(key), quote(value)
+        # converting all values to strings because that's how they're stored
+        key, value = quote(key), quote(str(value))
         path = build_path(index_path, "node", index_name, key, value)
         params = None
         return self.request.get(path, params)
@@ -911,7 +912,8 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        key, value = quote(key), quote(value)
+        # converting all values to strings because that's how they're stored
+        key, value = quote(key), quote(str(value))
         path = build_path(index_path, edge_path, index_name, key, value)
         params = None
         return self.request.get(path, params)
@@ -1015,7 +1017,7 @@ class Neo4jClient(Client):
 
         """
         data = self._remove_null_values(data)
-        edge_params = dict(outV=outV,label=label,inV=inV)
+        edge_params = dict(outV=outV,label=label,inV=inV,label_var=self.config.label_var)
         params = dict(data=data,index_name=index_name,keys=keys)
         params.update(edge_params)
         script = self.scripts.get("create_indexed_edge")
