@@ -10,9 +10,8 @@ returning a Response object.
 """
 import httplib2
 
-import bulbs
 from bulbs.base import Response
-from .utils import json, get_logger, quote, urlencode, encode_dict
+from .utils import json, get_logger, quote, urlencode
 
 
 log = get_logger(__name__)
@@ -39,10 +38,6 @@ def not_found(http_resp):
     raise LookupError(http_resp)
     #return None
 
-def method_not_allowed(http_resp):
-    # TODO: is there a better error for this than SystemError?
-    raise SystemError(http_resp)
-
 def conflict(http_resp):
     raise SystemError(http_resp)
 
@@ -54,12 +49,9 @@ RESPONSE_HANDLERS = {200:ok,
                      204:no_content,
                      400:bad_request,
                      404:not_found,
-                     405:method_not_allowed,
                      409:conflict,
                      500:server_error}
 
-# good posture good brain
-
 class Request(object):
     """Used for connecting to the a REST server over HTTP."""
 
@@ -74,11 +66,7 @@ class Request(object):
         """
         self.config = config
         self.content_type = content_type
-        self.user_agent = "bulbs/%s" % (bulbs.__version__)
-        if config.timeout is not None:
-            self.http = httplib2.Http(timeout=int(config.timeout))
-        else:
-            self.http = httplib2.Http()    
+        self.http = httplib2.Http()    
         self._add_credentials(config.username, config.password)
         self._initialize()
 
@@ -191,21 +179,15 @@ class Request(object):
         log.debug("%s body: %s ", method, body)
                     
     def _build_request_args(self, path, method, params):
-        headers = {'Accept': 'application/json',
-                   'User-Agent': self.user_agent}
+        headers = {'Accept': 'application/json'}
         body = None
 
         uri = "%s/%s" % (self.config.root_uri.rstrip("/"), path.lstrip("/"))
 
         if params and method is GET:
-            params = encode_dict(params)
             uri = "%s?%s" % (uri, urlencode(params))
-            content_type = "%s ; charset=utf-8" % self.content_type
-            get_headers = {'Content-Type': content_type}
-            headers.update(get_headers)
         
         if params and (method in [PUT, POST, DELETE]):
-            #params = encode_dict(params)
             body = json.dumps(params)
             post_headers = {'Content-Type': self.content_type}
             headers.update(post_headers)
@@ -216,13 +198,4 @@ class Request(object):
         if username and password:
             self.http.add_credentials(username, password)
 
-    # how to reuse the http object?
-    def __getstate__(self):
-        state = self.__data__.copy()
-        del state['http']
-        return state
-
-    def __setstate__(self, state):
-        state['http'] = httplib2.Http()
-        self.__data__ = state
 
